Locations class

Constructors

Locations()

Properties

codeRoot Directory?
getter/setter pair
distRoot Directory?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isValid bool
no setter
pluginYaml File?
no setter
pubspecYaml File?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staticPluginRoot Directory?
getter/setter pair

Methods

dist(String id, String version) File
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited