ComboOption class

Constructors

ComboOption(String value, {String? label, Widget? widget})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final
widget Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
withLabel(String label) ComboOption

Operators

operator ==(Object other) bool
The equality operator.
inherited