helpers/amenity_describer library

Classes

AmenityDescriber
Describes an OsmChange object by calling AmenityIndicators. Without a single indicator added it just prints OsmChange.typeAndName.
AmenityIndicator
Amenity indicator controls the information present in a POI tile. Used by AmenityDescriber to build a tile content. It usually returns a single icon for a missing property, and maybe some more information when the property is present.