login method

  1. @override
Future<AuthToken?> login(
  1. BuildContext context
)
override

Open a login panel, perform the authentication, and receive a token. Should return null if the process was manually cancelled, or throw an AuthException if it failed.

Implementation

@override
Future<AuthToken?> login(BuildContext context) async => null;