loadUserDetails abstract method

Future<UserDetails> loadUserDetails(
  1. AuthToken token
)

Makes a query to the server asking for user details. It gets called when opening the app, and after logging in.

If the request fails, throw an AuthException.

Implementation

Future<UserDetails> loadUserDetails(AuthToken token);