isValid method
Checks whether the token is valid. Should return false if anything in the token data prompts it won't work.
Implementation
bool isValid() => true;
Checks whether the token is valid. Should return false if anything in the token data prompts it won't work.
bool isValid() => true;