needsRefresh method
Check whether the token is obsolete. If the token has an expiration date, override this method.
Implementation
bool needsRefresh() => false;
Check whether the token is obsolete. If the token has an expiration date, override this method.
bool needsRefresh() => false;