DrawingStyle class

Constructors

DrawingStyle({required Color color, bool thin = false, bool dashed = false})
const

Properties

casing → Color
no setter
color → Color
final
dashed → bool
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stroke → double
no setter
thin → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

kDefaultStroke → const double