iconLabels property
Whether to show labels as icons. Very few standard fields have labels set, so it might not work.
Implementation
final bool iconLabels;
Whether to show labels as icons. Very few standard fields have labels set, so it might not work.
final bool iconLabels;