Labels for fields, whose tag keys are in this set, will be colored green or red depending on whether they have values. The idea is that those fields need to be filled usually.
final Set<String> mandatoryKeys;