LineString class

Inheritance

Constructors

LineString(Iterable<LatLng> nodes)

Properties

bounds → LatLngBounds
no setteroverride
center → LatLng
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
nodes → List<LatLng>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

closestPoint(LatLng point) → LatLng
distanceToPoint(LatLng point, {bool inMeters = true}) → double
getLengthInMeters() → double
intersects(LineString other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited