Polygon class

Inheritance
Implementers

Constructors

Polygon(Iterable<LatLng> nodes)

Properties

bounds → LatLngBounds
no setteroverride
center → LatLng
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(LatLng point) bool
containsPolygon(Polygon poly) bool
findPointOnSurface() → LatLng
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited