LegendController class
- Inheritance
-
- Object
- ChangeNotifier
- LegendController
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- iconsInLegend ↔ bool
-
If false, does not add presets with icons defined to the legend. See
fixPreset for adding icons.
getter/setter pair
-
legend
→ List<
LegendItem> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
fixPreset(
String preset, {Color? color, MultiIcon? icon}) → void -
getLegendItem(
OsmChange amenity) → LegendItem? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
resetFixes(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateLegend(
List< OsmChange> amenities, {Locale? locale, int maxItems = 6}) → Future -
Updates legend colors for
amenities. The list should be ordered closest to farthest. The function tries to reuse colors. Thelocaleis needed to translate labels.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
kLegendColors
→ const List<
NamedColor>