LegendItem class

Constructors

LegendItem({Color? color, MultiIcon? icon, required String label})
LegendItem.other(String label)

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
icon MultiIcon?
final
isOther bool
no setter
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited