MultiIcon class

This class encapsulates monochrome icons. It replaces IconData class, allowing for raster and vector images. An image should be rectangular, recommended dimensions are 256×256.

Constructors

MultiIcon({IconData? fontIcon, String? emoji, Uint8List? imageData, Uint8List? svgData, Uint8List? siData, String? imageUrl, String? asset, String? tooltip})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltip String?
final

Methods

getWidget({BuildContext? context, double? size, Color? color, String? semanticLabel, bool icon = true, bool fixedSize = true}) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
withTooltip(String? tooltip) MultiIcon

Operators

operator ==(Object other) bool
The equality operator.
inherited