PluginLocalizations class

Constructors

PluginLocalizations()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
translate(Locale locale, String key, {Map<String, dynamic>? args, Map<String, dynamic>? data}) String
translateList(Locale locale, String key, {Map<String, dynamic>? data}) List<String>
translateN(Locale locale, String key, int count, {Map<String, dynamic>? args, Map<String, dynamic>? data}) String

Operators

operator ==(Object other) bool
The equality operator.
inherited