PoiDescriber class abstract

Description generator for POI tiles. Instances of this interface are passed to PoiTile so it can provide all the information needed to assess the correctness of the data.

Implementers

Constructors

PoiDescriber()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describe(Located element) TextSpan
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited