SimpleDescriber class

Simple describer returns the OsmChange.typeAndName and nothing else. It will be crossed out if disused.

Implemented types

Constructors

SimpleDescriber()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describe(Located element) TextSpan
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited