toElement method
Constructs a new element from this change after the object has been uploaded. Or for uploading.
Implementation
OsmElement toElement({int? newId, int? newVersion}) {
throw UnimplementedError();
}
Constructs a new element from this change after the object has been uploaded. Or for uploading.
OsmElement toElement({int? newId, int? newVersion}) {
throw UnimplementedError();
}