hasRelevantKey method

bool hasRelevantKey(
  1. Map<String, String> tags
)

Tests whether the object has tags matching this field. The purpose is to check whether the field has a non-empty value.

Implementation

bool hasRelevantKey(Map<String, String> tags) => tags.containsKey(key);