icon property
Icon for the field. Displayed only in the standard fields block in the full-page editor.
Implementation
final IconData? icon;
Icon for the field. Displayed only in the standard fields block in the full-page editor.
final IconData? icon;