models/imagery library

Classes

Imagery
A data container for an imagery layer. Fields are based on the editor layer index, and just the identifier and type are required. This is the super-class for the multitude of implementations, including TMS, WMS, and vector tiles.

Enums

ImageryCategory
Imagery category, a subset of the Editor Layer Index categories.