initialize method
Initialize layer state. May be useful when needed to make some async
request, e.g. to download data from an URL. Executed by imageryProvider
when the layer is chosen.
Implementation
Future<void> initialize() async {}
Initialize layer state. May be useful when needed to make some async
request, e.g. to download data from an URL. Executed by imageryProvider
when the layer is chosen.
Future<void> initialize() async {}