models/located library

Classes

Located
Super-class for everything that can be displayed on the map. Obviously, as the editor only supports points, this class contains only the point location. Also has three service getters to learn the state of the object. If not needed, it's safe to use default values: true for isNew and false for everything else.