isNew property
bool
get
isNew
Whether this object has been created in the editor and not uploaded to the server yet.
Implementation
bool get isNew => true;
Whether this object has been created in the editor and not uploaded to the server yet.
bool get isNew => true;