BaseNote class

Implementers

Constructors

BaseNote({required LatLng location, int? id, required int? type, DateTime? created, bool deleting = false})
BaseNote.fromJson(Map<String, dynamic> data)
factory

Properties

created → DateTime
final
deleting ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
isChanged → bool
no setter
isNew → bool
no setter
location → LatLng
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revert() → bool
Reverts changes if possible (except isNew) and returns true if successful.
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

kNoteGeohashPrecision → const int