OsmId class

OSM identifier: a type and a number.

Constructors

OsmId(OsmElementType type, int ref)
const
OsmId.fromString(String s)
Parses a string like "n123" into OsmId with the type from the letter (e.g. node for "n") and the number from the rest.
factory

Properties

fullRef String
Returns a representation like "node/123", to use in building website URLs.
no setter
hashCode int
The hash code for this object.
no setteroverride
ref int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type OsmElementType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns a string like "n123" for a node with id=123. Can be parsed back into an OsmId with OsmId.fromString.
override

Operators

operator ==(Object other) bool
The equality operator.
override