OsmMember class

An OSM relation member. Contains of an OSM id and an optional role.

Constructors

OsmMember(OsmId id, [String? role])
const
OsmMember.fromString(String s)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id OsmId
final
role String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type OsmElementType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited