models/plugin library

Classes

Plugin
Plugin metadata. Same as PluginData, but with added service methods for retrieving localizations and assets. Data read from the plugin metadata is final, but the active flag can be changed in runtime. Same with instance: it is initialized when the plugin is made active, and reset when it is disabled.
PluginData
Plugin metadata. Basically an identifier and a dictionary from the bundled yaml file.

Properties

kApiVersion PluginVersion
final

Exceptions / Errors

PluginLoadException
Thrown only when loading a plugin. Prints the enclosed exception as well.