Plugin class abstract

Plugin metadata. Same as PluginData, but with added service methods for retrieving localizations and assets. Data read from the plugin metadata is final, but the active flag can be changed in runtime. Same with instance: it is initialized when the plugin is made active, and reset when it is disabled.

Inheritance

Constructors

Plugin({required String id, required Map<String, dynamic> data, required Directory directory})

Properties

active bool
getter/setter pair
apiVersion PluginVersionRange?
no setterinherited
author String?
no setterinherited
data Map<String, dynamic>
finalinherited
description String
no setterinherited
directory Directory
final
hashCode int
The hash code for this object.
no setterinherited
homepage Uri?
no setterinherited
icon MultiIcon?
no setteroverride
id String
finalinherited
installed bool
finalinherited
instance EveryDoorPlugin?
getter/setter pair
intro String?
no setter
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url Uri?
no setterinherited
version PluginVersion
finalinherited

Methods

getLocalizationsBranch(String prefix) PluginLocalizationsBranch
loadIcon(String name, [String? tooltip]) MultiIcon
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveDirectory(String name) Directory
resolvePath(String name) File
showIntro(BuildContext context) Future<void>
toString() String
A string representation of this object.
inherited
translate(BuildContext context, String key, {Map<String, dynamic>? args}) String

Operators

operator ==(Object other) bool
The equality operator.
inherited