PluginData class

Plugin metadata. Basically an identifier and a dictionary from the bundled yaml file.

Implementers

Constructors

PluginData(String id, Map<String, dynamic> data, {bool installed = true})

Properties

apiVersion → PluginVersionRange?
no setter
author → String?
no setter
data → Map<String, dynamic>
final
description → String
no setter
hashCode → int
The hash code for this object.
no setteroverride
homepage → Uri?
no setter
icon → MultiIcon?
no setter
id → String
final
installed → bool
final
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → Uri?
no setter
version → PluginVersion
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override