PluginVersionRange class

Constructors

PluginVersionRange(dynamic data)

Properties

hashCode int
The hash code for this object.
no setterinherited
max PluginVersion
latefinal
min PluginVersion
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(PluginVersion version) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited