plugins/events library

Classes

PluginEvents
Plugin events wrapper. Use this class to listen to events. Listeners are automatically deactivated when the plugin is inactive. All callback should be asynchronous functions, even when they don't use await.