install method
Set up listeners and stuff. This gets called when the plugin is enabled, either during the start-up, or after the installation.
Implementation
Future<void> install(EveryDoorApp app) async {}
Set up listeners and stuff. This gets called when the plugin is enabled, either during the start-up, or after the installation.
Future<void> install(EveryDoorApp app) async {}