uninstall method

Future<void> uninstall(
  1. EveryDoorApp app
)

Uninstall plugin. Usually does not need to be overridden, but can e.g. store data somewhere. Called when the plugin is manually uninstalled. NOT called when the app is closed and unloaded.

Implementation

Future<void> uninstall(EveryDoorApp app) async {}