plugins/interface library

Classes

EveryDoorApp
This class is used by plugins to interact with the app. It might be rebuilt often, and contains references to Riverpod ref and BuildContext (if applicable). And also a ton of convenience methods.