EveryDoorApp class abstract

This class is used by plugins to interact with the app. It might be rebuilt often, and contains references to Riverpod ref and BuildContext (if applicable). And also a ton of convenience methods.

Constructors

EveryDoorApp()

Properties

events PluginEvents
no setter
hashCode int
The hash code for this object.
no setterinherited
logger → Logger
no setter
onRepaint → dynamic Function()?
no setter
plugin Plugin
no setter
preferences PluginPreferences
no setter
providers PluginProviders
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAuthProvider(String name, AuthProvider provider) → void
Adds an authentication provider. It is not currently possible to override an AuthController. It is also not possible to replace the generic providers such as "osm", or use providers defined in other plugins (because of the mandatory prefix).
addMode(BaseModeDefinition mode) → void
Adds an editor mode. Cannot replace existing ones, use removeMode for that.
addOverlay(Imagery imagery) → void
Adds an overlay layer. You only need to specify the Imagery.id and Imagery.buildLayer, but also set the Imagery.overlay to true. For plugins, it would make sense to either use the metadata static file, or to instantiate ExtOverlay.
auth(String name) AuthController
Returns a controller for an authentication provider. Use "osm" to get OSM request headers.
eachMode(dynamic callback(BaseModeDefinition)) → void
Do something with every mode installed. Useful for dynamically adding and removing buttons and layers, for example.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMode(String name) → void
Removes the mode. Can remove both a pre-defined mode (like "notes"), and a plugin-added one.
repaint() → void
When available, initiates the screen repaint. Useful for updating the plugin settings screen.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited