eachMode method
Do something with every mode installed. Useful for dynamically adding and removing buttons and layers, for example.
Implementation
void eachMode(Function(BaseModeDefinition) callback) {
}
Do something with every mode installed. Useful for dynamically adding and removing buttons and layers, for example.
void eachMode(Function(BaseModeDefinition) callback) {
}