isTracking property
bool
get
isTracking
Learn whether we're moving the map automatically with the user movement.
Implementation
bool get isTracking;
Learn whether we're moving the map automatically with the user movement.
bool get isTracking;