screens/editor library

Classes

PoiEditorPage
An object editor page. Expects an OSM-like sourced object, that is, an OsmChange. In particular, the object needs to have tags that behave in accordance with OSM model, e.g. for lifecycle prefixes. For editing Located you would need to create your own pages.