PoiEditorPage class

An object editor page. Expects an OSM-like sourced object, that is, an OsmChange. In particular, the object needs to have tags that behave in accordance with OSM model, e.g. for lifecycle prefixes. For editing Located you would need to create your own pages.

Inheritance

Constructors

PoiEditorPage({OsmChange? amenity, Preset? preset, LatLng? location, bool isModified = false})
const

Properties

amenity OsmChange?
The object to edit. Set to null and fill preset and location if creating a new one.
final
hashCode int
The hash code for this object.
no setterinherited
isModified bool
Set to true if the object has been modified externally without saving to the internal database. For example, when the object has been edited in a bottom sheet, but then this editor page has been called with it.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
location → LatLng?
The location for a new object.
final
preset Preset?
For new objects, a preset from which to fill the tags and get field list. Should be specified (for new objects). Needs to have both Preset.addTags and Preset.fields non-empty. When the preset type is PresetType.nsi, the actual preset is detected based on Preset.addTags.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited