isModified property

bool isModified
final

Set to true if the object has been modified externally without saving to the internal database. For example, when the object has been edited in a bottom sheet, but then this editor page has been called with it.

Implementation

final bool isModified;