preset property

Preset? preset
final

For new objects, a preset from which to fill the tags and get field list. Should be specified (for new objects). Needs to have both Preset.addTags and Preset.fields non-empty. When the preset type is PresetType.nsi, the actual preset is detected based on Preset.addTags.

Implementation

final Preset? preset;