BaseModeDefinition class abstract

Inheritance
Implementers

Constructors

BaseModeDefinition()

Properties

buttons Iterable<MapButton>
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
name String
no setter
overlays Iterable<Imagery>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addMapButton(MapButton button) → void
addOverlay(Imagery imagery) → void
dispose() → void
Discards any resources used by the object.
inherited
getIcon(BuildContext context, bool outlined) MultiIcon
getNearestChanges(LatLngBounds bounds, {int maxCount = 200, bool filter = true}) Future<List<OsmChange>>
isOurKind(OsmChange element) bool
mapLayers() List<Widget>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
parseKinds(dynamic data) List<ElementKindImpl>?
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeMapButton(String id) → void
toString() String
A string representation of this object.
inherited
updateFromJson(Map<String, dynamic> data, Plugin plugin) → void
updateNearest(LatLngBounds bounds) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited