MicromappingModeDefinition class abstract
- Inheritance
-
- Object
- ChangeNotifier
- BaseModeDefinition
- MicromappingModeDefinition
Constructors
Properties
-
finalinherited
- enableZoomingIn ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- legend ↔ LegendController
-
getter/setter pair
- name → String
-
no setterinherited
-
nearestPOI
↔ List<
OsmChange> -
getter/setter pair
-
otherPOI
↔ List<
LatLng> -
getter/setter pair
-
overlays
→ Iterable<
Imagery> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
addMapButton(
MapButton button) → void -
inherited
-
addOverlay(
Imagery imagery) → void -
inherited
-
buildMarker(
int index, OsmChange element, bool isZoomedIn) → Widget -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
getIcon(
BuildContext context, bool outlined) → MultiIcon -
override
-
getNearestChanges(
LatLngBounds bounds, {int maxCount = 200, bool filter = true}) → Future< List< OsmChange> > -
inherited
-
isOurKind(
OsmChange element) → bool -
override
-
mapLayers(
) → List< Widget> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
openEditor(
BuildContext context, LatLng location) → void -
parseKinds(
dynamic data) → List< ElementKindImpl> ? -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeMapButton(
String id) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateFromJson(
Map< String, dynamic> data, Plugin plugin) → void -
override
-
updateLegend(
BuildContext context) → void -
updateNearest(
LatLngBounds bounds) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- kMicroStuffInList → const int