hasFloatingButton property
When there is a floating button on the screen, zoom buttons need to be moved higher.
Implementation
final bool hasFloatingButton;
When there is a floating button on the screen, zoom buttons need to be moved higher.
final bool hasFloatingButton;