CustomMapController class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mapController ↔ MapController?
-
getter/setter pair
-
mapKey
↔ GlobalKey<
State< ?StatefulWidget> > -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
zoomListener
↔ dynamic Function(Iterable<
LatLng> )? -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setLocation(
{LatLng? location, double? zoom}) → void -
toString(
) → String -
A string representation of this object.
inherited
-
zoomToFit(
Iterable< LatLng> locations) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited