OverlayButtonWidget class

Inheritance

Constructors

OverlayButtonWidget({Key? key, required Alignment alignment, EdgeInsets? padding, required void onPressed(BuildContext), void onLongPressed(BuildContext)?, required IconData icon, bool enabled = true, String? tooltip, bool safeBottom = false, bool safeRight = false})
const

Properties

alignment Alignment
To which corner of the map should the button be aligned.
final
enabled bool
Set to false to hide the button.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
Icon to display.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onLongPressed → void Function(BuildContext)?
Function to call on long tap.
final
onPressed → void Function(BuildContext)
Function to call when the button is pressed.
final
padding EdgeInsets?
Padding for the button.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeBottom bool
Add safe area to the bottom padding. Enable when the map is full-screen.
final
safeRight bool
Add safe area to the right side padding.
final
tooltip String?
Tooltip and semantics message.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited