RadioField constructor

const RadioField({
  1. required List<String> options,
  2. List<String>? labels,
  3. List<Widget>? widgetLabels,
  4. String? value,
  5. List<String>? values,
  6. bool wrap = false,
  7. bool multi = false,
  8. bool keepFirst = false,
  9. bool keepOrder = false,
  10. dynamic onChange(
    1. String?
    )?,
  11. dynamic onMultiChange(
    1. List<String>
    )?,
})

Creates a widget. Only options are technically required, but you should also specify either of value or values, and a callback function between onChange and onMultiChange.

Implementation

const RadioField({
  required this.options,
  this.labels,
  this.widgetLabels,
  this.value,
  this.values,
  this.wrap = false,
  this.multi = false,
  this.keepFirst = false,
  this.keepOrder = false,
  this.onChange,
  this.onMultiChange,
});