keepFirst property
Keep the first options before all others. Use only for a fake first option, e.g. that launches a dialog. Warning: this implies the first option can never be a value.
Implementation
final bool keepFirst;
Keep the first options before all others. Use only for a fake first option, e.g. that launches a dialog. Warning: this implies the first option can never be a value.
final bool keepFirst;