onChange property
A callback function for when the value (singular) changes. If multiple values can be chosen, they will be joined with a semicolon.
Implementation
final Function(String?)? onChange;
A callback function for when the value (singular) changes. If multiple values can be chosen, they will be joined with a semicolon.
final Function(String?)? onChange;