value property
The currently present tag value. Can be empty of course. Can also contain several values joined by a semicolon ("yes;no").
Implementation
final String? value;
The currently present tag value. Can be empty of course. Can also contain several values joined by a semicolon ("yes;no").
final String? value;