OSM tag key for this field. If the field does not use this
attribute (or adds more keys, e.g. contact:phone for phone),
do override the hasRelevantKey method.
Tag prerequisites for moving this field into the main block.
If a field is in the "more fields" block, it's collapsed by default.
When a prerequisite matches, it is moved to the main "fields" block.