hasRelevantKey method
Tests whether the object has tags matching this field. The purpose is to check whether the field has a non-empty value.
Implementation
@override
bool hasRelevantKey(Map<String, String> tags) {
if (type == ComboType.multi) {
for (final k in tags.keys) if (k.startsWith(key)) return true;
return false;
}
return tags.containsKey(key);
}