AmenityIndicator class abstract
Amenity indicator controls the information present in a POI tile. Used by AmenityDescriber to build a tile content. It usually returns a single icon for a missing property, and maybe some more information when the property is present.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applies(
OsmChange amenity) → bool - Whether this indicator is useful for this object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
whenMissing(
OsmChange amenity) → String? - Returns an icon for when a property is missing.
-
whenPresent(
OsmChange amenity) → String? - Returns an icon and maybe an abridged value for a property.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited