AuthController class

This controller manages an AuthProvider, saving a token to the local storage and keeping user details in value ready to display.

Inheritance

Constructors

AuthController(String name, AuthProvider provider)

Properties

authorized bool
no setter
endpoint String
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
name String
Controller name. Should be overridden, and unique, otherwise tokens would get mixed up.
final
provider AuthProvider
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenKey String
no setter
value UserDetails?
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
fetchToken(BuildContext? context) Future<AuthToken>
getApiKey(BuildContext? context) Future<String?>
getAuthHeaders(BuildContext? context) Future<Map<String, String>>
loadData() Future<void>
loadToken() Future<AuthToken?>
login(BuildContext context) Future<void>
logout() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
saveToken(AuthToken? token) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited