EditorFields class
A group of fields in the editor. Only the fields list is mandatory.
Constructors
-
EditorFields({required Iterable<
PresetField> fields, String? title, bool collapsed = true, bool iconLabels = false, Set<String> mandatoryKeys = const {}})
Properties
- collapsed → bool
-
If the title is present, whether to show the group folded
when opening the editor.
final
-
fields
→ Iterable<
PresetField> -
A list of fields to present in this group.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconLabels → bool
-
Whether to show labels as icons. Very few standard fields have labels set,
so it might not work.
final
-
mandatoryKeys
→ Set<
String> -
Labels for fields, whose tag keys are in this set, will be colored
green or red depending on whether they have values. The idea is that
those fields need to be filled usually.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Title of the group. If present, an expansion tile is used to mark it.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited