MultiIcon class
This class encapsulates monochrome icons. It replaces IconData class, allowing for raster and vector images. An image should be rectangular, recommended dimensions are 256×256.
Constructors
Properties
Methods
-
getWidget(
{BuildContext? context, double? size, Color? color, String? semanticLabel, bool icon = true, bool fixedSize = true}) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
withTooltip(
String? tooltip) → MultiIcon
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited