helpers/plugin_i18n library
Classes
- PluginLocalizations
- PluginLocalizationsBranch
- Localizations wrapper for passing to various parts of code that need only small parts of the metadata tree. For example, a tree preset would need "preset.tree" branch for translations. This class allows to hide the context.