PluginLocalizationsBranch class abstract
Localizations wrapper for passing to various parts of code that need only small parts of the metadata tree. For example, a tree preset would need "preset.tree" branch for translations. This class allows to hide the context.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
translate(
Locale locale, String key, {Map< String, dynamic> ? args}) → String -
translateCtx(
BuildContext context, String key, {Map< String, dynamic> ? args}) → String -
translateList(
Locale locale, String key) → List< String>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited