models/field library
Classes
- FieldPrerequisite
- Tag dependency definition. Basically a structure that defines which tags and which values should or should not be preset in a tag list. See https://github.com/ideditor/schema-builder/blob/main/README.md#prerequisitetag
- PresetField
-
Field definition. Each field type needs to subclass this one.
There are multiple examples in the
fieldsdirectory. - PresetFieldContext