FieldPrerequisite class
Tag dependency definition. Basically a structure that defines which tags and which values should or should not be preset in a tag list. See https://github.com/ideditor/schema-builder/blob/main/README.md#prerequisitetag
Constructors
-
FieldPrerequisite({String? key, List<
String> ? values, String? keyNot, List<String> ? valuesNot}) -
const
-
FieldPrerequisite.fromJson(Map<
String, dynamic> data) -
factory
Properties
Methods
-
matches(
Map< String, String> tags) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited