prerequisite property
Tag prerequisites for moving this field into the main block. If a field is in the "more fields" block, it's collapsed by default. When a prerequisite matches, it is moved to the main "fields" block.
Implementation
final FieldPrerequisite? prerequisite;