Located class abstract
Super-class for everything that can be displayed on the map. Obviously, as the editor only supports points, this class contains only the point location. Also has three service getters to learn the state of the object. If not needed, it's safe to use default values: true for isNew and false for everything else.
Constructors
- Located()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDeleted → bool
-
Whether this object is still present on a server, but was deleted
in the editor. Also might mean setting a deleted flag on the server,
so it's possible to have isDeleted true and isModified false.
no setter
- isModified → bool
-
Whether this object was modified in the editor. Should return true
when isNew or isDeleted are true.
no setter
- isNew → bool
-
Whether this object has been created in the editor and not uploaded
to the server yet.
no setter
- location → LatLng
-
The location of the object.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uniqueId → String
-
Unique id for usage as keys in various widgets.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited