isDeleted property
bool
get
isDeleted
Whether this object is still present on a server, but was deleted in the editor. Also might mean setting a deleted flag on the server, so it's possible to have isDeleted true and isModified false.
Implementation
bool get isDeleted => false;