MapNote class
Constructors
Properties
-
final
- created → DateTime
-
finalinherited
- deleting ↔ bool
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
getter/setter pairinherited
- isChanged → bool
-
no setterinherited
- isNew → bool
-
no setterinherited
- location → LatLng
-
finalinherited
- message ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → int?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
revert(
) → bool -
Reverts changes if possible (except isNew) and returns true if successful.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- dbType → const int
- kMaxLength → const int