OsmNote class
Constructors
-
OsmNote({int? id, required LatLng location, List<
OsmNoteComment> comments = const [], DateTime? created, bool deleting = false}) -
OsmNote.fromJson(Map<
String, dynamic> data) -
factory
Properties
-
no setter
-
comments
→ List<
OsmNoteComment> -
final
- created → DateTime
-
finalinherited
- deleting ↔ bool
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNewComments → bool
-
no setter
- id ↔ int?
-
getter/setter pairinherited
- isChanged → bool
-
no setteroverride
- isNew → bool
-
no setterinherited
- location → LatLng
-
finalinherited
- message → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → int?
-
finalinherited
Methods
-
getNoteTitle(
) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
revert(
) → bool -
Reverts changes if possible (except isNew) and returns true if successful.
override
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited