Plugin metadata. Same as PluginData, but with added service methods
for retrieving localizations and assets. Data read from the plugin
metadata is final, but the active flag can be changed in runtime.
Same with instance: it is initialized when the plugin is made active,
and reset when it is disabled.