Preset class

Constructors

Preset({required String id, List<PresetField> fields = const [], List<PresetField> moreFields = const [], bool onArea = true, required Map<String, String> addTags, Map<String, String?> removeTags = const {}, required String name, String? subtitle, MultiIcon? icon, LocationSet? locationSet, Map<String, dynamic>? fieldData, PresetType type = PresetType.normal, bool noStandard = false})
const
Preset.fixme(String title, {String? subtitle})
factory
Preset.fromJson(Map<String, dynamic> data)
factory
Preset.fromNSIJson(Map<String, dynamic> data)
factory
Preset.poi(Map<String, dynamic> row)
factory

Properties

addTags Map<String, String>
final
fieldData Map<String, dynamic>?
final
fields List<PresetField>
final
hashCode int
The hash code for this object.
no setteroverride
icon MultiIcon?
final
id String
final
isGeneric bool
no setter
locationSet → LocationSet?
final
moreFields List<PresetField>
final
name String
final
noStandard bool
final
onArea bool
final
removeTags Map<String, String?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String
no setter
type PresetType
final

Methods

doAddTags(OsmChange change) → void
doRemoveTags(OsmChange change) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
withFields(List<PresetField> fields, List<PresetField> moreFields) Preset
withSubtitle(String subtitle) Preset

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decodeTags(Map<String, dynamic>? tags) Map<String, String?>
decodeTagsSkipNull(Map<String, dynamic>? tags) Map<String, String>