PluginVersion class
Constructors
- PluginVersion(dynamic version, [bool flatNumbering = true])
-
Constructs a version instance. Possible types for the
versionare: - PluginVersion.exact(int? _major, int _minor)
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fresherThan(
PluginVersion? version) → bool -
nextMajor(
) → PluginVersion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator <(
PluginVersion other) → bool -
operator <=(
PluginVersion other) → bool -
operator ==(
Object other) → bool -
The equality operator.
override
-
operator >(
PluginVersion other) → bool
Static Properties
- zero → PluginVersion
-
final