PluginEvents class
Plugin events wrapper. Use this class to listen to events. Listeners are automatically deactivated when the plugin is inactive. All callback should be asynchronous functions, even when they don't use await.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDownload(
dynamic callback(LatLng)) → void - Invoked when the "download" button is pressed.
-
onEditorFields(
EditorFieldsCallback callback) → void - Invoked when the editor pane prepares its fields. Here you can insert or replace some fields, even the entire page.
-
onModeCreated(
dynamic callback(BaseModeDefinition mode)) → void -
Listen to editing mode instantiations. The
callbackis called on each mode when initializing the plugin, and then every time a new mode is added. Thecallbackshould be an async function. -
onUpload(
dynamic callback()) → void - Invoked when the "upload" button is pressed.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited