EveryDoorPlugin class
Parent class for every plugin. None of the methods need to be implemented, although it would be weird.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildSettingsPane(
EveryDoorApp app, BuildContext context) → Widget? - Returns a widget for the plugin settings. The best option would be to return a Column with a list of ListTile. Use EveryDoorApp.preferences for storing those. Use EveryDoorApp.repaint method when you usually would call setState().
-
install(
EveryDoorApp app) → Future< void> - Set up listeners and stuff. This gets called when the plugin is enabled, either during the start-up, or after the installation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
uninstall(
EveryDoorApp app) → Future< void> - Uninstall plugin. Usually does not need to be overridden, but can e.g. store data somewhere. Called when the plugin is manually uninstalled. NOT called when the app is closed and unloaded.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited