ExtOverlay class
Properties
attribution
→ String ?
Imagery attribution. Displayed in a corner for most maps.
final inherited
best
→ bool
Whether this imagery is the best imagery for the region.
Might affect sorting.
final inherited
build
→ Widget Function(BuildContext context , dynamic data )
final
category
→ ImageryCategory ?
Imagery category. Not really used anywhere.
final inherited
hashCode
→ int
The hash code for this object.
no setter inherited
icon
→ MultiIcon ?
Icon to display.
final inherited
id
→ String
Identifier of the imagery. Should be unique for every layer.
final inherited
kUserAgentPackageName
→ String
Package name to send to servers.
final inherited
name
→ String ?
Display name, shown in lists when choosing an imagery layer.
final inherited
overlay
→ bool
Whether this imagery is an overlay. Not used currently.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
update
→ Future Function(LatLngBounds ) ?
final
updateInMeters
→ int
final
Methods
buildLayer ({bool reset = false })
→ Widget
Builds the widgets to add to the FlutterMap. Note that this method
is called on every widget rebuild, which can happen like 60 times a second.
Do cache things.
override
initialize ()
→ Future <void >
Initialize layer state. May be useful when needed to make some async
request, e.g. to download data from an URL. Executed by imageryProvider
when the layer is chosen.
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited