addAuthProvider method
Adds an authentication provider. It is not currently possible to override an AuthController. It is also not possible to replace the generic providers such as "osm", or use providers defined in other plugins (because of the mandatory prefix).
Implementation
void addAuthProvider(String name, AuthProvider provider) {
if (provider.title == null) {
throw ArgumentError("Title is required for a provider");
}
}