plugins/preferences library
Classes
- PluginPreferences
-
Shadows the shared_preferences module from plugins. Nothing wrong with
using it directly, but this allows us to track preferences by plugin.
Basically adds a prefix to every key, and accesses the app-wide
SharedPreferencesWithCacheinstance.