PluginPreferences class
Shadows the shared_preferences module from plugins. Nothing wrong with
using it directly, but this allows us to track preferences by plugin.
Basically adds a prefix to every key, and accesses the app-wide
SharedPreferencesWithCache instance.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBool(
String name) → bool? -
getDouble(
String name) → double? -
getInt(
String name) → int? -
getString(
String name) → String? -
getStringList(
String name) → List< String> ? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setBool(
String name, bool value) → Future< void> -
setDouble(
String name, double value) → Future< void> -
setInt(
String name, int value) → Future< void> -
setString(
String name, String value) → Future< void> -
setStringList(
String name, List< String> value) → Future<void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited