Properties
-
compass
→ double?
-
Get the compass direction.
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isTracking
→ bool
-
Learn whether we're moving the map automatically with the user
movement.
no setter
-
location
↔ LatLng
-
Get the current location of the main screen.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
zoom
← double
-
Changes the map zoom level.
no getter
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited