EditorButton class abstract

A container representing a button on the editor pane.

Constructors

EditorButton()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, OsmChange amenity) MaterialButton
Builds the button. Properties to override are usually title, onPressed, color, and textColor.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldDisplay(OsmChange amenity) bool
Returns true if the button should be displayed. Note that this should rely on a general property and not some easily changed state, for example, on an ElementKind. You can use the MaterialButton.enabled flag instead.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited