shouldDisplay abstract method
Returns true if the button should be displayed. Note that this should rely on a general property and not some easily changed state, for example, on an ElementKind. You can use the MaterialButton.enabled flag instead.
Implementation
bool shouldDisplay(OsmChange amenity);