IconMarker class
- Inheritance
-
- Object
- SizedMarker
- IconMarker
Constructors
- IconMarker(MultiIcon icon)
Properties
- alignment → Alignment
-
finalinherited
- child → Widget
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
finalinherited
- rotate → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
finalinherited
Methods
-
buildMarker(
{Key? key, required LatLng point}) → Marker -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited