CustomMap class
General map widget for every map in Every Door. Encloses layer management, interaction, additional buttons etc etc.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CustomMap
Constructors
-
CustomMap({Key? key, void onTap(LatLng, double (LatLng))?, CustomMapController? controller, List<
Widget> layers = const [], List<MapButton> buttons = const [], bool drawZoomButtons = true, bool hasFloatingButton = false, bool drawStandardButtons = true, bool drawPinMarker = true, bool faintWalkPath = true, bool interactive = true, bool track = true, bool onlyOSM = false, bool allowRotation = true, bool updateState = false}) -
const
Properties
- allowRotation → bool
-
final
-
final
- controller → CustomMapController?
-
final
- drawPinMarker → bool
-
final
- drawStandardButtons → bool
-
final
- drawZoomButtons → bool
-
final
- faintWalkPath → bool
-
final
- hasFloatingButton → bool
-
When there is a floating button on the screen, zoom buttons
need to be moved higher.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interactive → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
layers
→ List<
Widget> -
final
- onlyOSM → bool
-
final
- onTap → void Function(LatLng, double (LatLng))?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- track → bool
-
final
- updateState → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited